@@ -27,7 +27,7 @@
 #include <PowerDevilSettings.h>
 
 #include <qtextstream.h>
-#include <QtDBus>
+#include <QDBusMessage>
 #include <QDebug>
 #include <QPropertyAnimation>
 
@@ -47,11 +47,11 @@
 
 PowerDevilUPowerBackend::PowerDevilUPowerBackend(QObject* parent)
     : BackendInterface(parent)
-    , m_displayDevice(Q_NULLPTR)
-    , m_brightnessControl(Q_NULLPTR)
-    , m_randrHelper(Q_NULLPTR)
-    , m_upowerInterface(Q_NULLPTR)
-    , m_kbdBacklight(Q_NULLPTR)
+    , m_displayDevice(nullptr)
+    , m_brightnessControl(nullptr)
+    , m_randrHelper(nullptr)
+    , m_upowerInterface(nullptr)
+    , m_kbdBacklight(nullptr)
     , m_kbdMaxBrightness(0)
     , m_lidIsPresent(false)
     , m_lidIsClosed(false)
